@@ -89,14 +89,14 @@ typedef enum _GstQuarkId
   GST_QUARK_MESSAGE_WARNING = 60,
   GST_QUARK_MESSAGE_INFO = 61,
   GST_QUARK_MESSAGE_BUFFERING = 62,
-  GST_QUARK_MESSAGE_STATE = 63,
+  GST_QUARK_MESSAGE_STATE_CHANGED = 63,
   GST_QUARK_MESSAGE_CLOCK_PROVIDE = 64,
   GST_QUARK_MESSAGE_CLOCK_LOST = 65,
   GST_QUARK_MESSAGE_NEW_CLOCK = 66,
   GST_QUARK_MESSAGE_STRUCTURE_CHANGE = 67,
   GST_QUARK_MESSAGE_SEGMENT_START = 68,
   GST_QUARK_MESSAGE_SEGMENT_DONE = 69,
-  GST_QUARK_MESSAGE_DURATION = 70,
+  GST_QUARK_MESSAGE_DURATION_CHANGED = 70,
   GST_QUARK_MESSAGE_ASYNC_DONE = 71,
   GST_QUARK_MESSAGE_REQUEST_STATE = 72,
   GST_QUARK_MESSAGE_STREAM_STATUS = 73,
@@ -179,11 +179,16 @@ typedef enum _GstQuarkId
   GST_QUARK_TAGS = 150,
   GST_QUARK_SUB_ENTRIES = 151,
   GST_QUARK_INFO = 152,
-  GST_QUARK_INFO_STRUCTURE = 153,
-  GST_QUARK_TIME_STRUCTURE = 154,
-  GST_QUARK_MESSAGE_TAG = 155,
-  GST_QUARK_EVENT_TAG = 156,
-  GST_QUARK_MAX = 157
+  GST_QUARK_MESSAGE_TAG = 153,
+  GST_QUARK_EVENT_TAG = 154,
+  GST_QUARK_MESSAGE_RESET_TIME = 155,
+  GST_QUARK_MESSAGE_TOC = 156,
+  GST_QUARK_EVENT_TOC_GLOBAL = 157,
+  GST_QUARK_EVENT_TOC_CURRENT = 158,
+  GST_QUARK_EVENT_SEGMENT_DONE = 159,
+  GST_QUARK_EVENT_STREAM_START = 160,
+  GST_QUARK_STREAM_ID = 161,
+  GST_QUARK_MAX = 162
 } GstQuarkId;
 
 extern GQuark _priv_gst_quark_table[GST_QUARK_MAX];
